==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRangeSliderValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescription } from "./WebRangeSliderValueDescription";
/**
 * @hidden
 */
export let WebRangeSliderValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRangeSliderValueDescriptionMetadata extends Base {
        static b(a) {
            if (WebRangeSliderValueDescriptionMetadata.a == null) {
                WebRangeSliderValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRangeSliderValueDescriptionMetadata.c(WebRangeSliderValueDescriptionMetadata.a);
            }
            if (a.j(WebRangeSliderValueDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRangeSliderValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RangeSliderValue");
            a.item("Lower", "Number:double");
            a.item("Upper", "Number:double");
        }
        static d(a) {
            WebRangeSliderValueDescriptionMetadata.b(a);
            a.aa("WebRangeSliderValue", () => new WebRangeSliderValueDescription());
            a.z("WebRangeSliderValue", WebRangeSliderValueDescriptionMetadata.a);
        }
    }
    WebRangeSliderValueDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRangeSliderValueDescriptionMetadata, 'WebRangeSliderValueDescriptionMetadata');
    WebRangeSliderValueDescriptionMetadata.a = null;
    return WebRangeSliderValueDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRangeSliderValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescription } from "./WebRangeSliderValueDescription";
/**
 * @hidden
 */
export let WebRangeSliderValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRangeSliderValueDescriptionMetadata extends Base {
        static b(a) {
            if (WebRangeSliderValueDescriptionMetadata.a == null) {
                WebRangeSliderValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRangeSliderValueDescriptionMetadata.c(WebRangeSliderValueDescriptionMetadata.a);
            }
            if (a.k(WebRangeSliderValueDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRangeSliderValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RangeSliderValue");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Lower", "Number:double");
            a.item("Upper", "Number:double");
        }
        static d(a) {
            WebRangeSliderValueDescriptionMetadata.b(a);
            a.ac("WebRangeSliderValue", () => new WebRangeSliderValueDescription());
            a.ab("WebRangeSliderValue", WebRangeSliderValueDescriptionMetadata.a);
        }
    }
    WebRangeSliderValueDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRangeSliderValueDescriptionMetadata, 'WebRangeSliderValueDescriptionMetadata');
    WebRangeSliderValueDescriptionMetadata.a = null;
    return WebRangeSliderValueDescriptionMetadata;
})();
